#
# spec file for package python-django-environ
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?sle15_python_module_pythons}
Name:           python-django-environ
Version:        0.12.0
Release:        1.3
Summary:        Django application configuration via environment variables
License:        MIT
Group:          Development/Languages/Python
URL:            https://github.com/joke2k/django-environ
Source:         https://files.pythonhosted.org/packages/source/d/django-environ/django_environ-%{version}.tar.gz
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-Django
BuildArch:      noarch
%python_subpackages

%description
Django-environ allows utilizing 12factor inspired environment
variables to configure Django applications.

%prep
%setup -q -n django_environ-%{version}

%build
%pyproject_wheel

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
LANG=en_US.UTF-8
%pytest -k "not test_db_parsing"

%files %{python_files}
%doc CHANGELOG.rst README.rst
%license LICENSE.txt
%{python_sitelib}/environ
%{python_sitelib}/django_environ-%{version}.dist-info

%changelog
* Mon Feb 24 2025 Dirk Müller <dmueller@suse.com>
- update to 0.12.0:
  * Include prefix in the ImproperlyConfigured error message
    [#513].
  * Add support for Python 3.12 and 3.13 #538.
  * Add support for Django 5.1 #535.
  * Add support for Django CockroachDB driver #509.
  * Add support for Django Channels #266.
  * Disabled inline comments handling by default due to potential
    side effects. While the feature itself is useful, the
    project's philosophy dictates that it should not be enabled
    by default for all users #499.
  * Removed support of Python 3.6, 3.7 and 3.8 #538.
  * Removed support of Django 1.x. #538.
* Sat Nov 23 2024 Dirk Müller <dmueller@suse.com>
- update to 0.11.2:
  * Revert "Add variable expansion." feature
  * Revert "Add interpolate argument to avoid resolving proxied
    values." feature
  * Added support for Django 4.2
  * Added support for secure Elasticsearch connections
  * Added variable expansion
  * Added capability to handle comments after #, after quoted values,
  * Added support for ``interpolate`` parameter
  * Use the core redis library by default if running Django >= 4.0
  * Value of dict can now contain an equal sign
  * Added support for Python 3.11.
  * Added ``CONN_HEALTH_CHECKS`` to database base options
  * Added ``encoding`` parameter to ``read_env`` with default
    value 'utf8'
  * Added support for Django 4.1
* Mon Jun 26 2023 Andreas Schneider <asn@cryptomilk.org>
- Use sle15_python_module_pythons
* Thu May 20 2021 pgajdos@suse.com
- %%check: use %%pytest macro
* Mon Mar 11 2019 John Vandenberg <jayvdb@gmail.com>
- Add LANG to %%check to fix Leap
* Mon Feb 18 2019 Jan Engelhardt <jengelh@inai.de>
- Avoid name repetition in summary; use noun phrasing.
* Sat Feb 16 2019 John Vandenberg <jayvdb@gmail.com>
- Initial spec for v0.4.5
